Here are some examples of Stack Overflow questions that speak to the need for something
like SuiteAs:

https://stackoverflow.com/questions/71273333/can-pytest-or-any-testing-tool-in-python-generate-the-unit-test-automatically
https://stackoverflow.com/questions/77409726/how-to-generate-unit-tests-for-python-using-src-and-test-folder-structure-prefe